@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # modRana N900 module
@@ -20,9 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-import os
 import subprocess
-from base_device_module import deviceModule
+from base_device_module import DeviceModule
 #N900 specific:
 import dbus.glib
 from core import gs
@@ -40,22 +38,23 @@ if gs.GUIString == "GTK":
   why dbus.glib ?
   if you import only "dbus", it can't find its mainloop for callbacks
   """
-else:
+elif gs.GUIString == "QML":
   from QtMobility.SystemInfo import QSystemScreenSaver
 
   """ ^^ back-light control"""
 
 import time
 
+
 def getModule(m, d, i):
-  return(device_n900(m, d, i))
+  return DeviceN900(m, d, i)
 
 
-class device_n900(deviceModule):
+class DeviceN900(DeviceModule):
   """A N900 modRana device-specific module"""
 
   def __init__(self, m, d, i):
-    deviceModule.__init__(self, m, d, i)
+    DeviceModule.__init__(self, m, d, i)
     self.rotationObject = None
     # start the N900 specific automatic GUI rotation support
     self.done = False
@@ -69,12 +68,15 @@ class device_n900(deviceModule):
     self.mceSignal = self.bus.get_object('com.nokia.mce', '/com/nokia/mce/signal')
     self.mceSignalInterface = dbus.Interface(self.mceSignal, 'com.nokia.mce.signal')
     self.mceSignalInterface.connect_to_signal("display_status_ind", self.screenStateChangedCallback)
-    print "N900: DBUS initialized"
+    print("N900: DBUS initialized")
 
     # Internet connectivity related
     self.connectivityStatus = False
     self.conicConnection = None
 
+    # Mainloop for headless location support
+    self.mainloop = None
+
     if gs.GUIString == "GTK":
       # liblocation
       self.lControl = None
@@ -85,11 +87,11 @@ class device_n900(deviceModule):
       # libconic
       self._conicConnect()
 
-    else:
+    elif gs.GUIString == "QML":
       print("N900 Qt screen saver controller created")
       self.qScreenSaver = QSystemScreenSaver()
 
-    print "N900 device specific module initialized"
+    print("N900 device specific module initialized")
 
   def _conicConnect(self):
     if self.conicConnection is None:
@@ -106,10 +108,10 @@ class device_n900(deviceModule):
       # load the rotation object
       rotationObject = self.startAutorotation()
       if rotationObject != False:
-        print "N900: rotation object loaded"
+        print("N900: rotation object loaded")
         self.rotationObject = rotationObject
       else:
-        print "N900: loading rotation object failed"
+        print("N900: loading rotation object failed")
 
       self.topWindow = gui.getGTKTopWindow()
 
@@ -118,7 +120,7 @@ class device_n900(deviceModule):
       self.rotationToggleButton = None
       self.soundToggleButton = None
       self._addHildonAppMenu()
-      print "N900: application menu added"
+      print("N900: application menu added")
 
       # window-active detection
       self.topWindow.connect('notify::is-active', self.windowIsActiveChangedCallback)
@@ -148,7 +150,7 @@ class device_n900(deviceModule):
       rotationMode = self.get('rotationMode', None)
       if rotationMode:
         self.setRotationMode(rotationMode)
-        print "rotation mode changed"
+        print("rotation mode changed")
     elif message == 'updateKeys':
       self._updateVolumeKeys()
 
@@ -159,13 +161,13 @@ class device_n900(deviceModule):
     return "Nokia N900"
 
   def getWinWH(self):
-    return (800, 480)
+    return 800, 480
 
   def startInFullscreen(self):
     return True
 
   def getSupportedGUIModuleIds(self):
-    return ["GTK", "QML"]
+    return ["GTK", "QML:harmattan", "QML:indep"]
 
   def startAutorotation(self):
     """start the GUI automatic rotation feature"""
@@ -175,12 +177,12 @@ class device_n900(deviceModule):
       rotationMode = self.get('rotationMode', "auto") # get last used mode
       lastModeNumber = self.getRotationModeNumber(rotationMode) # get last used mode number
       rObject = n900_maemo5_portrait.FremantleRotation(self.ossoAppName, main_window=self.topWindow,
-        mode=lastModeNumber)
-      print "N900 rotation object initialized"
+                                                       mode=lastModeNumber)
+      print("N900 rotation object initialized")
       return rObject
     except Exception, e:
-      print e
-      print "initializing N900 rotation object failed"
+      print("initializing N900 rotation object failed")
+      print(e)
 
   def setRotationMode(self, rotationMode):
     rotationModeNumber = self.getRotationModeNumber(rotationMode)
@@ -206,7 +208,7 @@ class device_n900(deviceModule):
     if gs.GUIString == "GTK":
     #      print("n900: pausing screen blanking in GTK GUI")
       self.mceRequest.req_display_blanking_pause()
-    else:
+    elif gs.GUIString == "QML":
     #      print("n900: pausing screen blanking in QML GUI")
       QSystemScreenSaver.setScreenSaverInhibit(self.qScreenSaver)
 
@@ -237,7 +239,7 @@ class device_n900(deviceModule):
           # check if text entry is in progress
           textEntry = self.m.get('textEntry', None)
           if textEntry:
-            if textEntry.isEntryBoxvisible():
+            if textEntry.isEntryBoxVisible():
               # we redraw modRana behind text entry box
               return
           display.disableRedraw(reason="N900 window is not active")
@@ -270,7 +272,7 @@ class device_n900(deviceModule):
       if msTimeout:
         banner.set_timeout(msTimeout)
     else:
-      print "n900: the N900 device module currently handles only Hildon based notifications"
+      print("n900: the N900 device module currently handles only Hildon based notifications")
 
   def hasButtons(self):
     """the N900 has the volume keys (2 buttons), the camera trigger (2 states)
@@ -291,11 +293,11 @@ class device_n900(deviceModule):
 
   def disableVolumeKeys(self):
     self.topWindow.window.property_change(gtk.gdk.atom_intern("_HILDON_ZOOM_KEY_ATOM"), gtk.gdk.atom_intern("INTEGER"),
-      32, gtk.gdk.PROP_MODE_REPLACE, [0]);
+                                          32, gtk.gdk.PROP_MODE_REPLACE, [0]);
 
   def enable_volume_cb(self, window=None):
     self.topWindow.window.property_change(gtk.gdk.atom_intern("_HILDON_ZOOM_KEY_ATOM"), gtk.gdk.atom_intern("INTEGER"),
-      32, gtk.gdk.PROP_MODE_REPLACE, [1]);
+                                          32, gtk.gdk.PROP_MODE_REPLACE, [1]);
 
   def _updateVolumeKeys(self):
     """check if volume keys should be used or not"""
@@ -362,7 +364,7 @@ class device_n900(deviceModule):
 
 
   def _toggle(self, toggleButton, key):
-    print "N900: key %s toggled" % key
+    print("N900: key %s toggled" % key)
     self.set(key, toggleButton.get_active())
 
   def _switchToMenu(self, toggleButton, menu):
@@ -371,7 +373,7 @@ class device_n900(deviceModule):
     self.set('needRedraw', True)
 
   def _updateAppMenu(self, key=None, value=None, oldValue=None):
-    print self.get("centred", True)
+    print(self.get("centred", True))
     if self.centeringToggleButton:
       self.centeringToggleButton.set_active(self.get("centred", True))
     if self.rotationToggleButton:
@@ -415,53 +417,67 @@ class device_n900(deviceModule):
       # use Qt Mobility for Qt
       return "qt_mobility"
 
-  def startLocation(self):
+  def startLocation(self, startMainLoop=False):
     """this will called by mod_location automatically"""
     self._libLocationStart()
+    if startMainLoop:
+      import gobject
+
+      self.mainloop = gobject.MainLoop()
+      print('N900: location: starting headless mainloop')
+      self.mainloop.run()
 
   def stopLocation(self):
     """this will called by mod_location automatically"""
     self._libLocationStop()
+    if self.mainloop:
+      print('N900: location: stopping headless mainloop')
+      self.mainloop.quit()
 
   def _libLocationStart(self):
     """start the liblocation based location update method"""
     try:
       try:
+        # as the location module drags inside gobject related modules
+        # that make the QML GUI segfault, we need to make sure they are not
+        # the module is not loaded when running the QML GUI
+        if gs.GUIString != "QML":
+          import location
         self.lControl = location.GPSDControl.get_default()
         self.lDevice = location.GPSDevice()
       except Exception, e:
-        print "n900 - location: - cant create location objects: %s" % e
+        print("n900 - location: - cant create location objects: %s" % e)
 
       try:
         self.lControl.set_properties(preferred_method=location.METHOD_USER_SELECTED)
       except Exception, e:
-        print "n900 - location: - cant set preferred location method: %s" % e
+        print("n900 - location: - cant set preferred location method: %s" % e)
 
       try:
         self.lControl.set_properties(preferred_interval=location.INTERVAL_1S)
       except Exception, e:
-        print "n900 - location: - cant set preferred location interval: %s" % e
+        print("n900 - location: - cant set preferred location interval: %s" % e)
       try:
         self.lControl.start()
-        print "** n900 - location: - GPS successfully activated **"
+        print("** n900 - location: - GPS successfully activated **")
         self.connected = True
       except Exception, e:
-        print "n900 - location: - opening the GPS device failed: %s" % e
+        print("n900 - location: - opening the GPS device failed: %s" % e)
         self.status = "No GPSD running"
 
       # connect callbacks
       #self.lControl.connect("error-verbose", self._liblocationErrorCB)
       self.lDevice.connect("changed", self._libLocationUpdateCB)
-      print "n900 - location: activated"
-    except:
+      print("n900 - location: activated")
+    except Exception, e:
       self.status = "No GPSD running"
-      print "n900 - location: - importing location module failed, please install the python-location package"
+      print("n900 - location: - importing location module failed, please install the python-location package")
+      print(e)
       self.sendMessage('notification:install python-location package to enable GPS#7')
 
 
   def _libLocationStop(self):
     """stop the liblocation based location update method"""
-
     print('n900 - location: stopping')
     if self.lControl:
       self.lControl.stop()
@@ -470,7 +486,6 @@ class device_n900(deviceModule):
       self.lDevice = None
       self.location = None
 
-
   def _liblocationErrorCB(self, control, error):
     if error == location.ERROR_USER_REJECTED_DIALOG:
       print("User didn't enable requested methods")
@@ -484,8 +499,7 @@ class device_n900(deviceModule):
       print("System error")
 
   def _libLocationUpdateCB(self, device):
-    """
-    from:  http://wiki.maemo.org/PyMaemo/Using_Location_API
+    """from:  http://wiki.maemo.org/PyMaemo/Using_Location_API
     result tuple in order:
     * mode: The mode of the fix
     * fields: A bitfield representing which items of this tuple contain valid data
@@ -501,13 +515,17 @@ class device_n900(deviceModule):
     * speed: Current speed in km/h (location.GPS_DEVICE_SPEED_SET)
     * eps: Speed accuracy
     * climb: Current rate of climb in m/s (location.GPS_DEVICE_CLIMB_SET)
-    * epc: Climb accuracy
-
-      """
+    * epc: Climb accuracy"""
     try:
       if device.fix:
-        fix = device.fix
+        # make sure the location module is imported, but not with QML GUI
+        # as the location module drags inside gobject related modules
+        # that make the QML GUI segfault, we need to make sure they are not
+        # the module is not loaded when running the QML GUI
+        if gs.GUIString != "QML":
+          import location
 
+        fix = device.fix
         self.set('fix', fix[0])
         """from liblocation reference:
         0 =	The device has not seen a satellite yet.
@@ -535,27 +553,26 @@ class device_n900(deviceModule):
 
         # TODO: remove when not needed
         if self.get('n900GPSDebug', False):
-          print "## N900 GPS debugging info ##"
-          print "fix tuple from the Location API:"
-          print fix
-          print "position,bearing,speed (in descending order):"
-          print self.get('pos', None)
-          print self.get('bearing', None)
-          print self.get('speed', None)
-          print "#############################"
-
-        """always set this key to current epoch once the location is updated
- so that modules can watch it and react"""
+          print("## N900 GPS debugging info ##")
+          print("fix tuple from the Location API:")
+          print(fix)
+          print("position,bearing,speed (in descending order):")
+          print(self.get('pos', None))
+          print(self.get('bearing', None))
+          print(self.get('speed', None))
+          print("#############################")
+          # always set this key to current epoch once the location is updated
+        # so that modules can watch it and react
         self.set('locationUpdated', time.time())
-        #        print "updating location"
+        #        print("updating location")
         self.set('needRedraw', True)
 
       else:
         self.status = "Unknown"
-        print "n900 - location: getting fix failed (on a regular update)"
+        print("n900 - location: getting fix failed (on a regular update)")
     except Exception, e:
       self.status = "Unknown"
-      print "n900 - location:getting fix failed (on a regular update + exception: %s)" % e
+      print("n900 - location:getting fix failed (on a regular update + exception: %s)" % e)
 
 
   # ** Internet connectivity **
@@ -582,9 +599,3 @@ class device_n900(deviceModule):
   def enableInternetConnectivity(self):
     """autoconnect to the Internet using DBUS"""
     subprocess.call(["sh", "modules/device_modules/n900_maemo5_autoconnect_dbus.sh"])
-
-if(__name__ == "__main__"):
-  a = n900({}, {})
-  a.update()
-  a.update()
-  a.update()
