@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Module for communication with various online services.
@@ -18,9 +17,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from modules.base_module import ranaModule
+from modules.base_module import RanaModule
+import traceback
+import sys
 import re
-import urllib
 import threading
 import time
 import geocoding
@@ -29,15 +29,16 @@ import local_search
 
 DEFAULT_GOOGLE_API_KEY = "ABQIAAAAv84YYgTIjdezewgb8xl5_xTKlax5G-CAZlpGqFgXfh-jq3S0yRS6XLrXE9CkHPS6KDCig4gHvHK3lw"
 
+
 def getModule(m, d, i):
-  return(onlineServices(m, d, i))
+  return OnlineServices(m, d, i)
 
 
-class onlineServices(ranaModule):
+class OnlineServices(RanaModule):
   """A module for talking to various online services"""
 
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.workerThreads = []
     self.drawOverlay = False
 
@@ -151,67 +152,10 @@ class onlineServices(ranaModule):
 
   # ** Geonames **
 
-  def elevFromGeonames(self, lat, lon):
-    """get elevation in meters for the specified latitude and longitude from geonames"""
-    url = 'http://ws.geonames.org/srtm3?lat=%f&lng=%f' % (lat, lon)
-    try:
-      query = urllib.urlopen(url)
-    except Exception, e:
-      "onlineServices: getting elevation from geonames returned an error"
-      return 0
-    return query.read()
-
   def elevFromGeonamesBatchAsync(self, latLonList, outputHandler, key, tracklog=None):
     flags = {'net': True}
     self._addWorkerThread(Worker._elevFromGeonamesBatch, [latLonList, tracklog], outputHandler, key, flags)
 
-  def elevFromGeonamesBatch(self, latLonList, threadCB):
-    """ get elevation in meters for the specified latitude and longitude from
-     geonames synchronously, it is possible to ask for up to 20 coordinates
-     at once
-    """
-    maxCoordinates = 20 #geonames only allows 20 coordinates per query
-    latLonElevList = []
-    mL = len(latLonList)
-    while len(latLonList) > 0:
-      if threadCB: # report progress to running thread
-        threadCB._setWorkStatusText("%d of %d done" % (mL - len(latLonList), mL))
-      tempList = latLonList[0:maxCoordinates]
-      #      latLonList = latLonList[maxCoordinates:len(latLonList)]
-
-      lats = ""
-      lons = ""
-      for point in tempList:
-        lats += "%f," % point[0]
-        lons += "%f," % point[1]
-
-        # TODO: maybe add switching ?
-        #      url = 'http://ws.geonames.org/astergdem?lats=%s&lngs=%s' % (lats,lons)
-      url = 'http://ws.geonames.org/srtm3?lats=%s&lngs=%s' % (lats, lons)
-      query = None
-      try:
-        query = urllib.urlopen(url)
-      except Exception, e:
-        print("online: getting elevation from geonames returned an error")
-        results = "0"
-        for i in range(1, len(tempList)):
-          results += " 0"
-      try:
-        if query:
-          results = query.read().split('\r\n')
-          query.close()
-      except Exception, e:
-        print("online: elevation string from geonames has a wrong format")
-        results = "0"
-        for i in range(1, len(tempList)):
-          results += " 0"
-
-      index = 0
-      for point in tempList: # add the results to the new list with elevation
-        latLonElevList.append((point[0], point[1], int(results[index])))
-        index += 1
-
-    return latLonElevList
 
   # ** Google Maps **
 
@@ -219,7 +163,7 @@ class onlineServices(ranaModule):
     """get a google maps wrapper instance"""
     key = self.get('googleAPIKey', DEFAULT_GOOGLE_API_KEY)
     if key is None:
-      print "onlineServices: a google API key is needed for using the google maps services"
+      print("onlineServices: a google API key is needed for using the google maps services")
       return None
       # only import when actually needed
     import googlemaps
@@ -228,7 +172,7 @@ class onlineServices(ranaModule):
     return gMap
 
   def googleLocalQuery(self, query, maxResults=0):
-    print "local search query: %s" % query
+    print("local search query: %s" % query)
     gMap = self.getGmapsInstance()
     if not maxResults:
       maxResults = int(self.get('GLSResults', 8))
@@ -236,7 +180,7 @@ class onlineServices(ranaModule):
     return local
 
   def googleLocalQueryLL(self, term, lat, lon):
-    query = self.constructGoogleQueryLL(term, lat, lon)
+    query = self.constructGoogleQuery(term, "%f,%f" % (lat, lon))
     local = self.googleLocalQuery(query)
     return local
 
@@ -245,37 +189,44 @@ class onlineServices(ranaModule):
     query = "%s loc:%s" % (term, location)
     return query
 
-  def googleDirectionsAsync(self, start, destination, outputHandler, key):
+  def googleDirectionsAsync(self, start, destination, outputHandler, key, waypoints=None):
     """a background running google directions query
        -> verbatim start and destination will be used in route description, no geocoding
        outputHandler will be provided with the results + the specified key string"""
+    if not waypoints: waypoints = []
     routeRequestSentTimestamp = time.time() # used for measuring how long the route lookup took
 
-    args = [(start, destination, routeRequestSentTimestamp)]
+    args = [(start, destination, routeRequestSentTimestamp, waypoints)]
     flags = {'net': True}
     self._addWorkerThread(Worker._onlineRouteLookup, args, outputHandler, key, flags)
 
-  def googleDirectionsLLAsync(self, start, destination, outputHandler, key):
+  def googleDirectionsLLAsync(self, start, destination, outputHandler, key, waypoints=None):
     """a background running Google Directions query
     - Lat Lon pairs version -> for geocoding the start/destination points (NOT first/last route points)
        outputHandler will be provided with the results + the specified key string"""
+    if not waypoints: waypoints = []
     routeRequestSentTimestamp = time.time() # used for measuring how long the route lookup took
-    args = [(start, destination, routeRequestSentTimestamp)]
+    args = [(start, destination, routeRequestSentTimestamp, waypoints)]
     flags = {'net': True}
     self._addWorkerThread(Worker._onlineRouteLookup, args, outputHandler, key, flags)
 
-  def googleDirections(self, start, destination):
+  def googleDirections(self, start, destination, waypoints=None):
     """ Get driving directions from Google.
     start and directions can be either coordinates tuples or address strings
     """
+    if not waypoints: waypoints = []
 
     otherOptions = ""
     if self.get('routingAvoidHighways', False): # optionally avoid highways
       otherOptions += 'h'
     if self.get('routingAvoidToll', False): # optionally avoid toll roads
       otherOptions += 't'
-
-    # respect travel mode
+    waypointOption = None
+    if waypoints: # waypoints are a list of strings
+      waypointOption = "%s" % waypoints[0]
+      for waypoint in waypoints[1:]:
+        waypointOption += "|%s" % waypoint
+      # respect travel mode
     mode = self.get('mode', None)
     if mode == 'cycle':
       type = "b"
@@ -291,14 +242,17 @@ class onlineServices(ranaModule):
     # the google language code is the second part of this whitespace delimited string
     googleLanguageCode = self.get('directionsLanguage', 'en en').split(" ")[1]
     dir['hl'] = googleLanguageCode
-    directions = self.tryToGetDirections(start, destination, dir, type, otherOptions)
+    directions = self.tryToGetDirections(start, destination, dir, type, otherOptions, waypointOption)
 
     return directions
 
-  def tryToGetDirections(self, start, destination, dir, travelMode, otherOptions, secondTime=False):
+  def tryToGetDirections(self, start, destination, dir, travelMode, otherOptions, waypointOption, secondTime=False):
     gMap = self.getGmapsInstance()
     parameters = travelMode + otherOptions
     dir['dirflg'] = parameters
+    if waypointOption:
+      dir['waypoints'] = waypointOption
+    dir['sensor'] = 'false'
     directions = ""
     # only import when actually needed
     import googlemaps
@@ -317,18 +271,22 @@ class onlineServices(ranaModule):
           print("onlineServices:GDirections:bad response to travel mode, trying default travel mode")
           self.set('needRedraw', True)
           directions = self.tryToGetDirections(start, destination, dir, travelMode="", otherOptions=otherOptions,
-            secondTime=True)
+                                               waypointOption=waypointOption, secondTime=True)
       else:
         print("onlineServices:GDirections:routing failed with exception googlemaps status code:%d" % e.status)
     except Exception, e:
-      print("onlineServices:GDirections:routing failed with non-googlemaps exception:\n%s" % e)
+      print("onlineServices:GDirections:routing failed with non-googlemaps exception")
+      print(e)
+      traceback.print_exc(file=sys.stdout) # find what went wrong
+
     self.set('needRedraw', True)
     return directions
 
-  def googleDirectionsLL(self, lat1, lon1, lat2, lon2):
+  def googleDirectionsLL(self, lat1, lon1, lat2, lon2, waypoints=None):
+    if not waypoints: waypoints = []
     start = (lat1, lon1)
     destination = (lat2, lon2)
-    return self.googleDirections(start, destination)
+    return self.googleDirections(start, destination, waypoints)
 
   def _googleReverseGeocode(self, lat, lon):
     gMap = self.getGmapsInstance()
@@ -522,14 +480,22 @@ class Worker(threading.Thread):
     if notification:
       notification.setWorkInProgressOverlayText(text)
 
+  def _updateProgress(self, progress):
+    """progress is a floating point number indicating progress on the current task
+    0.0 -> 0%
+    0.5 -> 50%
+    1.0 -> 100%
+    """
+    self.progress = progress
+
   # Google
   def _onlineRouteLookup(self, query):
     """this method online route lookup and is called by the worker thread"""
-    (start, destination, routeRequestSentTimestamp) = query
+    (start, destination, routeRequestSentTimestamp, waypoints) = query
     print("worker: routing from %s to %s" % (start, destination))
     self._setWorkStatusText("online routing in progress...")
     # get the route
-    directions = self.online.googleDirections(start, destination)
+    directions = self.online.googleDirections(start, destination, waypoints)
     self._setWorkStatusText("online routing done   ")
     # return result to the thread to handle
     return directions, start, destination, routeRequestSentTimestamp
@@ -578,13 +544,20 @@ class Worker(threading.Thread):
   def _elevFromGeonamesBatch(self, latLonList, tracklog):
     try:
       self._setWorkStatusText("online elevation lookup starting...")
-      results = self.online.elevFromGeonamesBatch(latLonList)
+      userAgent = self.online.modrana.configs.getUserAgent()
+      results = geonames.elevBatchSRTM(latLonList, self._geonamesCallback, userAgent)
       self._setWorkStatusText("online elevation lookup done   ")
       return results, tracklog
     except Exception, e:
-      print('onlineServices: exception during elevation lookup:\n', e)
+      print('onlineServices: exception during elevation lookup')
+      print(e)
+      traceback.print_exc(file=sys.stdout) # find what went wrong
       return None, tracklog
 
+  def _geonamesCallback(self, progress):
+    percentDone = 100 - int(100 * progress)
+    self._setWorkStatusText("online elevation lookup %d %% done" % percentDone)
+
   def _onlineWikipediaSearch(self, query):
     self._setWorkStatusText("online Wikipedia search in progress...")
     result = self.online.wikipediaSearch(query)
