@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Module for managing tracklogs.
@@ -18,17 +17,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 import os
 
 def getModule(m,d,i):
-  return(tracklogManager(m,d,i))
+  return TracklogManager(m,d,i)
 
-class tracklogManager(ranaModule):
+class TracklogManager(RanaModule):
   """Module for managing tracklogs"""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.scrollDict = {}
     self.currentNumItems = 0
     self.LTModule = None
@@ -53,7 +52,6 @@ class tracklogManager(ranaModule):
           self.set("needRedraw", True)
       elif message == "down":
         if (scroll + 1) < self.currentNumItems:
-          print "down"
           scroll += 1
           self.set("needRedraw", True)
       elif message == "reset":
@@ -99,15 +97,15 @@ class tracklogManager(ranaModule):
       path = self.LTModule.getActiveTracklogPath()
       currentCategory = self.get('currentTracCat', None)
       if currentCategory:
-        print "changing category for:"
-        print "%s" % path
-        print "to: %s" % currentCategory
+        print("changing category for:")
+        print("%s" % path)
+        print("to: %s" % currentCategory)
         self.LTModule.setTracklogPathCategory(path, currentCategory)
 
     elif message == 'setupColorMenu':
-      m = self.m.get('showGPX', None)
+      m = self.m.get('showTracklogs', None)
       if m:
-        m.setupChooseDistColorMenu('tracklogTools', '|showGPX:colorFromRegister|tracklogManager:setupToolsSubmenu|set:menu:tracklogTools')
+        m.setupChooseDistColorMenu('tracklogTools', '|showTracklogs:colorFromRegister|tracklogManager:setupToolsSubmenu|set:menu:tracklogTools')
 
     elif message == 'setupToolsSubmenu':
       self.setupToolsSubmenu()
@@ -120,7 +118,7 @@ class tracklogManager(ranaModule):
 
   def deleteTracklog(self, path):
     # delete a tracklog
-    print "deleting tracklog:%s" % path
+    print("deleting tracklog:%s" % path)
     # from cache
     self.LTModule.deleteTrackFromCache(path)
     # from loaded tracklogs
@@ -248,7 +246,7 @@ class tracklogManager(ranaModule):
       if track.trackpointsList and track.trackpointsList[0]:
         firstPoint = track.trackpointsList[0][0]
         (lat,lon) = (firstPoint.latitude, firstPoint.longitude)
-        action3 = "mapView:recentre %f %f|set:showTrackFilename:%s|showGPX:makeVisible|set:menu:None" % (lat, lon, track.filename)
+        action3 = "mapView:recentre %f %f|set:showTrackFilename:%s|showTracklogs:makeVisible|set:menu:None" % (lat, lon, track.filename)
         menus.drawButton(cr, x3, y3, dx, dy, "show on map", "generic", action3)
       else:
         menus.drawButton(cr, x3, y3, dx, dy, "can't show on map#no points", "generic", 'set:menu:tracklogManager#tracklogInfo')
@@ -261,7 +259,6 @@ class tracklogManager(ranaModule):
       # * draw an info box
       menus.drawButton(cr, x4, y4+dy, w, h1-(y4+dy), "", "generic", "set:menu:tracklogManager#tracklogInfo")
 
-      pointCount = 0
       if track.trackpointsList:
         pointCount = len(track.trackpointsList[0])
       else:
@@ -271,7 +268,7 @@ class tracklogManager(ranaModule):
       if track.elevation == True:
         units = self.m.get('units', None)
         if units:
-          print track.routeInfo['firstElevation']
+#          print(track.routeInfo['firstElevation'])
           maxString = units.m2CurrentUnitString(track.routeInfo['maxElevation'], 2, False)
           minString = units.m2CurrentUnitString(track.routeInfo['minElevation'], 2, False)
           text += "\nmaximum elevation: %s\nminimum elevation: %s" % (maxString, minString)
@@ -298,11 +295,11 @@ class tracklogManager(ranaModule):
     menus.addItem('tracklogTools', 'active#set', 'generic', 'set:currentTrack:%s|tracklogManager:loadTrackProfile|set:menu:None' % track.filename)
     menus.addItem('tracklogTools', 'inactive#set', 'generic', 'set:currentTrack:None|tracklogManager:unLoadTrackProfile|set:menu:None')
     if isVisible:
-      menus.addItem('tracklogTools', 'toggle#visible', 'generic', 'set:showTrackFilename:%s|showGPX:toggleVisible|tracklogManager:setupToolsSubmenu' % track.filename)
+      menus.addItem('tracklogTools', 'toggle#visible', 'generic', 'set:showTrackFilename:%s|showTracklogs:toggleVisible|tracklogManager:setupToolsSubmenu' % track.filename)
     else:
-      menus.addItem('tracklogTools', 'toggle#invisible', 'generic', 'set:showTrackFilename:%s|showGPX:toggleVisible|tracklogManager:setupToolsSubmenu' % track.filename)
-    menus.addItem('tracklogTools', 'visible#all tracks', 'generic', 'showGPX:allVisible|set:menu:tracklogManager#tracklogInfo')
-    menus.addItem('tracklogTools', 'visible#no tracks', 'generic', 'showGPX:inVisible|set:menu:tracklogManager#tracklogInfo')
+      menus.addItem('tracklogTools', 'toggle#invisible', 'generic', 'set:showTrackFilename:%s|showTracklogs:toggleVisible|tracklogManager:setupToolsSubmenu' % track.filename)
+    menus.addItem('tracklogTools', 'visible#all tracks', 'generic', 'showTracklogs:allVisible|set:menu:tracklogManager#tracklogInfo')
+    menus.addItem('tracklogTools', 'visible#no tracks', 'generic', 'showTracklogs:clearVisible|set:menu:tracklogManager#tracklogInfo')
 
     if isVisible:
       colorName = visibleTracklogs[currentPath]['colorName']
@@ -343,12 +340,4 @@ class tracklogManager(ranaModule):
         originalTracklog.trackpointsList[0][index].elevation = onlinePoint[2]
         index += 1
       originalTracklog.modified() # make the tracklog update
-      originalTracklog.replaceFile() # replace the old tracklog file
-
-
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
+      originalTracklog.replaceFile() # replace the old tracklog file
\ No newline at end of file
